<?php

namespace Drupal\views_csv_source\Plugin\views\sort;

use Drupal\Core\Form\FormStateInterface;
use Drupal\views\Plugin\views\sort\SortPluginBase;
use Drupal\views_csv_source\Plugin\views\query\ViewsCsvQuery;

/**
 * Base sort handler for views_csv_source.
 *
 * @ViewsSort("views_csv_source_sort")
 */
class ViewsCsvSort extends SortPluginBase {

  /**
   * {@inheritDoc}
   */
  public function defineOptions(): array {
    $options = parent::defineOptions();
    $options['key'] = ['default' => ''];
    return $options;
  }

  /**
   * {@inheritDoc}
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state): void {
    parent::buildOptionsForm($form, $form_state);
    $form['key'] = [
      '#title' => $this->t('Column Selector'),
      '#description' => $this->t('Choose a key'),
      '#default_value' => $this->options['key'],
      '#required' => TRUE,
    ];
    // Get the query.
    $query = $this->view->query;
    assert($query instanceof ViewsCsvQuery, 'Query must be of type ViewsCsvQuery');

    // Ensure the query is of the correct type.
    if ($headers = $query->getCsvHeader()) {
      $form['key']['#type'] = 'select';
      $form['key']['#options'] = array_combine($headers, $headers);
    }
    else {
      // Fall back to text value if CSV has not been selected.
      $form['key']['#type'] = 'textfield';
    }
  }

  /**
   * {@inheritDoc}
   */
  public function query(): void {
    $this->query->addOrderBy(NULL, $this->options['key'], $this->options['order']);
  }

}
